@@ -24,8 +24,10 @@
     environment
 """
 
-import subprocess
+import logging
 import os
+import subprocess
+import sys
 from .libkas import kasplugin
 from .context import create_global_context
 from .config import Config
@@ -45,24 +47,19 @@ class Shell:
         Implements a kas plugin that opens a shell within the kas environment.
     """
 
-    @classmethod
-    def get_argparser(cls, parser):
-        """
-            Returns a parser for the shell plugin
-        """
-        sh_prs = parser.add_parser('shell',
-                                   help='Run a shell in the build '
-                                   'environment.')
+    name = 'shell'
+    helpmsg = 'Run a shell in the build environment.'
 
-        sh_prs.add_argument('config',
-                            help='Config file')
-        sh_prs.add_argument('--skip',
-                            help='Skip build steps',
-                            default=[])
-        sh_prs.add_argument('-k', '--keep-config-unchanged',
+    @classmethod
+    def setup_parser(cls, parser):
+        """
+            Setup the argument parser for the shell plugin
+        """
+
+        parser.add_argument('-k', '--keep-config-unchanged',
                             help='Skip steps that change the configuration',
                             action='store_true')
-        sh_prs.add_argument('-c', '--command',
+        parser.add_argument('-c', '--command',
                             help='Run command',
                             default='')
 
@@ -74,7 +71,7 @@ class Shell:
         if args.cmd != 'shell':
             return False
 
-        ctx = create_global_context()
+        ctx = create_global_context(args)
         ctx.config = Config(args.config, None, None)
 
         macro = Macro()
@@ -133,5 +130,7 @@ class ShellCommand(Command):
         if self.cmd:
             cmd.append('-c')
             cmd.append(self.cmd)
-        subprocess.call(cmd, env=ctx.environ,
-                        cwd=ctx.build_dir)
+        ret = subprocess.call(cmd, env=ctx.environ, cwd=ctx.build_dir)
+        if ret != 0:
+            logging.error('Shell returned non-zero exit status %d', ret)
+            sys.exit(ret)
